summaryrefslogtreecommitdiffstats
path: root/kradio3/plugins/timecontrol/timecontrol.h
diff options
context:
space:
mode:
Diffstat (limited to 'kradio3/plugins/timecontrol/timecontrol.h')
-rw-r--r--kradio3/plugins/timecontrol/timecontrol.h35
1 files changed, 18 insertions, 17 deletions
diff --git a/kradio3/plugins/timecontrol/timecontrol.h b/kradio3/plugins/timecontrol/timecontrol.h
index f38bae9..7d9b946 100644
--- a/kradio3/plugins/timecontrol/timecontrol.h
+++ b/kradio3/plugins/timecontrol/timecontrol.h
@@ -18,41 +18,42 @@
#ifndef KRADIO_TIMECONTROL_H
#define KRADIO_TIMECONTROL_H
-#include <qobject.h>
-#include <qtimer.h>
+#include <tqobject.h>
+#include <tqtimer.h>
#include "../../src/include/alarm.h"
#include "../../src/include/plugins.h"
#include "../../src/include/timecontrol_interfaces.h"
-// well, it has to be a QObject :( , but only for
-// receiving QTimer - timeouts
+// well, it has to be a TQObject :( , but only for
+// receiving TQTimer - timeouts
-class TimeControl : public QObject,
+class TimeControl : public TQObject,
public PluginBase,
public ITimeControl
{
Q_OBJECT
+ TQ_OBJECT
protected:
AlarmVector m_alarms;
Alarm const * m_waitingFor; // m_alarmTimer is exactly for this date/time
int m_countdownSeconds; // in seconds
- QDateTime m_countdownEnd;
+ TQDateTime m_countdownEnd;
- QTimer m_alarmTimer;
- QTimer m_countdownTimer;
+ TQTimer m_alarmTimer;
+ TQTimer m_countdownTimer;
- mutable QDateTime m_nextAlarm_tmp; // used to recognize nextAlarm changes
+ mutable TQDateTime m_nextAlarm_tmp; // used to recognize nextAlarm changes
public:
- TimeControl (const QString &name);
+ TimeControl (const TQString &name);
~TimeControl();
- virtual QString pluginClassName() const { return "TimeControl"; }
+ virtual TQString pluginClassName() const { return "TimeControl"; }
- virtual const QString &name() const { return PluginBase::name(); }
- virtual QString &name() { return PluginBase::name(); }
+ virtual const TQString &name() const { return PluginBase::name(); }
+ virtual TQString &name() { return PluginBase::name(); }
virtual bool connectI (Interface *i);
virtual bool disconnectI (Interface *i);
@@ -76,18 +77,18 @@ RECEIVERS:
bool stopCountdown();
ANSWERS:
- QDateTime getNextAlarmTime () const;
+ TQDateTime getNextAlarmTime () const;
const Alarm* getNextAlarm () const;
const AlarmVector & getAlarms () const { return m_alarms; }
int getCountdownSeconds () const { return m_countdownSeconds; }
- QDateTime getCountdownEnd () const;
+ TQDateTime getCountdownEnd () const;
// slots for receiving timeout messages of timers
protected slots:
- virtual void slotQTimerAlarmTimeout();
- virtual void slotQTimerCountdownTimeout();
+ virtual void slotTQTimerAlarmTimeout();
+ virtual void slotTQTimerCountdownTimeout();
};